%global name webvirtmgr
%global version 4.8.9
%global release 1.192.ge1c7abb

Name:           %{name}
Version:        %{version}
Release:        %{release}%{?dist}
Summary:        WebVirtMgr panel for manage virtual machine

License:        Apache Licence, Version 2.0
URL:            http://github.com/retspen/webvirtmgr
Source0:        https://github.com/NethServer/webvirtmgr/archive/master.tar.gz

%if 0%{?rhel} >= 7 || 0%{?fedora}
%bcond_without systemd	# enabled
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
BuildRequires:    systemd
%else
%bcond_with systemd	# disabled
Requires(post): chkconfig
Requires(postun): /sbin/service
Requires(preun): /sbin/service
Requires(preun): chkconfig
%endif

BuildArch:      noarch
BuildRequires:  python-setuptools

Requires:       python-setuptools libvirt-python libxml2-python python-websockify python-gunicorn python-lockfile
%if 0%{?rhel} >= 7
Requires:	python-django
%else
Requires:       python-django15
%endif

Requires:       libvirt qemu-kvm

%description
WebVirtMgr is a libvirt-based Web interface for managing virtual machines.
It allows you to create and configure new domains, and adjust a domain resource allocation.
A VNC viewer presents a full graphical console to the guest domain.
KVM is currently the only hypervisor supported.

%prep
%setup -n %{name}-master

%build
%{__python} setup.py build

%install
%{__python} setup.py install --skip-build --install-lib=%{python_sitelib}/%{name} --root %{buildroot}
cp -r templates %{buildroot}%{python_sitelib}/%{name}/
cp -r webvirtmgr/static %{buildroot}%{python_sitelib}/%{name}/

mkdir -p %{buildroot}%{python_sitelib}/%{name}/conf
cp conf/gunicorn.conf.py %{buildroot}%{python_sitelib}/%{name}/conf/gunicorn.conf.py


%if %{with systemd}
mkdir -p %{buildroot}%{_unitdir}
install -m0644 conf/init/webvirtmgr-console.service %{buildroot}%{_unitdir}/webvirtmgr-console.service
install -m0644 conf/init/webvirtmgr.service %{buildroot}%{_unitdir}/webvirtmgr.service
%else
mkdir -p %{buildroot}%{_sysconfdir}/init
cp conf/init/webvirtmgr-redhat.conf %{buildroot}%{_sysconfdir}/init/webvirtmgr.conf
mkdir -p %{buildroot}%{_sysconfdir}/init.d
cp conf/initd/webvirtmgr-console-redhat %{buildroot}%{_sysconfdir}/init.d/webvirtmgr-console
%endif

cp manage.py %{buildroot}%{python_sitelib}/%{name}/
rm -rf %{buildroot}%{_bindir}/manage.py

%post
%if %{with systemd}
%systemd_post webvirtmgr.service
%systemd_post webvirtmgr-console.service
%else
/sbin/chkconfig --add webvirtmgr
/sbin/chkconfig --add webvirtmgr-console
%endif

%preun
%if %{with systemd}
%systemd_preun webvirtmgr.service
%systemd_preun webvirtmgr-console.service
%else
if [ $1 -eq 0 ]; then
    /sbin/stop webvirtmgr >/dev/null 2>&1 || :
    /sbin/chkconfig --del webvirtmgr
    /sbin/service webvirtmgr stop >/dev/null 2>&1 || :
    /sbin/chkconfig --del webvirtmgr-console
fi
%endif

%postun
%if %{with systemd}
%systemd_postun_with_restart webvirtmgr.service
%systemd_postun_with_restart webvirtmgr-console.service
%else
if [ $1 -ge 1 ]; then
    /sbin/restart webvirtmgr >/dev/null 2>&1 || :
    /sbin/service webvirtmgr-console restart >/dev/null 2>&1 || :
fi
%endif


%files
%defattr(-,root,root)
%{python_sitelib}/*
%config %{python_sitelib}/%{name}/conf/gunicorn.conf.py
%if %{with systemd}
%{_unitdir}/webvirtmgr.service
%{_unitdir}/webvirtmgr-console.service
%else
%{_sysconfdir}/init/*
%{_sysconfdir}/init.d/*
%endif

%changelog
* Thu Feb 18 2016 Giacomo Sanchietti <giacomo.sanchietti@nethesis.it> - 192.ge1c7abb.ns7
- systemd service: fix working dir (Giacomo Sanchietti <giacomo.sanchietti@nethesis.it>)
- spec: mark gunicorn.conf.py as config file (Giacomo Sanchietti <giacomo.sanchietti@nethesis.it>)
- RPM: support for rhel 7 (Giacomo Sanchietti <giacomo.sanchietti@nethesis.it>)
- Merge pull request #588 from forumi0721/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Merge pull request #584 from mattface/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Add support qed (forumi0721 <forumi0721@gmail.com>)
- Fixup an un-needed import (Matt Hart <matthew.hart@linaro.org>)
- Properly parse the capabilities XML to confirm KVM support (Matt Hart <matthew.hart@linaro.org>)
- Merge pull request #580 from darkpixel/patch-1 (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Don't hide ISOs with uppercase names (Aaron C. de Bruyn <aaron@heyaaron.com>)
- Fix #565 (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Update README.rst (Retspen <anatoliy.guskov@gmail.com>)
- Fix url (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Some info for #226 (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Added support Debian 8 (Retspen <anatoliy.guskov@gmail.com>)
- Fixed #547 (Retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #545 from brenard/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Fix SPICE console template to encrypt websocket connection if page is access over HTTPS (Benjamin Renard <bn8@zionetrix.net>)
- Rename webvirtmgr-novnc in webvirtmgr-console in initd/deploy scripts (Benjamin Renard <brenard@zionetrix.net>)
- Fix connhost / connport detection (Thanks @tboulogne on #498) (Benjamin Renard <brenard@zionetrix.net>)
- Raise on get_connection_infos() exception and add connection infos debug message (Benjamin Renard <brenard@zionetrix.net>)
- Improve get_console_listen_addr() method (Benjamin Renard <brenard@zionetrix.net>)
- Fix Spice console menu style (Benjamin Renard <brenard@zionetrix.net>)
- Add fullscreen button on VNC/Spice console page (Benjamin Renard <brenard@zionetrix.net>)
- Add send-keys menu to Spice console (Benjamin Renard <brenard@zionetrix.net>)
- Check and warn if token cookie is not found (Benjamin Renard <brenard@zionetrix.net>)
- Add possibility to pass options to webvirtmgr-console daemon (Benjamin Renard <brenard@zionetrix.net>)
- Fixed #541 (Retspen <anatoliy.guskov@gmail.com>)
- Fixed travis (Retspen <anatoliy.guskov@gmail.com>)
- Changed dev scripts (Retspen <anatoliy.guskov@gmail.com>)
- Fixed #541 (Retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #537 from rainsun/dev (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Too strict validation for dir type (RainSun <rainsun@users.noreply.github.com>)
- Merge branch 'master' of github.com:retspen/webvirtmgr (Retspen <anatoliy.guskov@gmail.com>)
- Fixed #527 (Retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #524 from ozalexo/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Fix for #436 (Alexey Ozerov <alexozerov@gmail.com>)
- Merge pull request #523 from tuvistavie/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Fix #436 (Retspen <anatoliy.guskov@gmail.com>)
- Fix too strict validation for LVM device. (Daniel Perez <daniel@claudetech.com>)
- Fix pep8 failure. (Daniel Perez <daniel@claudetech.com>)
- Fix regexp in form (Retspen <anatoliy.guskov@gmail.com>)
- Fix some lines (Retspen <anatoliy.guskov@gmail.com>)
- Fix #522 (Retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #501 from ainoniwa/djang_url (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- URL expression to use the Django URL dispatcher in views (ruy <ruy.suzu7@gmail.com>)
- URL expression to use the Django URL dispatcher in templates (ruy <ruy.suzu7@gmail.com>)
- Merge pull request #497 from alexdo/hotfix/console-ssh-type-error (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- CS: Properly break line to stay within line length (Alexander Dormann <alexdo@alexdo.de>)
- Adds reference to github PR #497 after creation (Alexander Dormann <alexdo@alexdo.de>)
- Fixes a TypeError just before SSH connect (Alexander Dormann <alexdo@alexdo.de>)
- Update README.rst (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Merge pull request #495 from edospadoni/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Merge pull request #496 from daniviga/upstream (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Fix spaces (Daniele Viganò <daniele@vigano.me>)
- Fix multiple pep8 violations (Daniele Viganò <daniele@vigano.me>)
- include python path in redhat-novnc (Edoardo Spadoni <edoardo.spadoni@nethesis.it>)
- Add RPM spec file and Upstart file. Fix novnc in console (Edoardo Spadoni <edoardo.spadoni@nethesis.it>)
- Merge pull request #494 from brenard/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Add WS_CERT parameter (Benjamin Renard <brenard@easter-eggs.com>)
- Update version (Retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #488 from brenard/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Fix cookies access in instusage (Benjamin Renard <brenard@easter-eggs.com>)
- Add support for console's socket on localhost (Benjamin Renard <brenard@easter-eggs.com>)
- Add support of SSH tunneling to access instance's console (Benjamin Renard <brenard@easter-eggs.com>)
- Display shutdown/suspend/save tabs only when is accessibled (Benjamin Renard <brenard@easter-eggs.com>)
- Fix typo (Benjamin Renard <brenard@easter-eggs.com>)
- Add support for spice console (Benjamin Renard <brenard@easter-eggs.com>)
- Adapt Shutdown tab message and title when the instance is shutoff (Benjamin Renard <brenard@easter-eggs.com>)
- Check graphic device exist before define password and show error message if not exist (Benjamin Renard <brenard@easter-eggs.com>)
- Check disk's image attribute before accessing in show_clone_disk() (Benjamin Renard <brenard@easter-eggs.com>)
- Add WS_PUBLIC_HOST variable to permit to define WS public host address (Benjamin Renard <brenard@easter-eggs.com>)
- Fix #476 (retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #474 from daniviga/random-mac (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Lowercase digits in hex address (Daniele Viganò <daniele@vigano.me>)
- Re-add a blank line (Daniele Viganò <daniele@vigano.me>)
- Change button label (Daniele Viganò <daniele@vigano.me>)
- Implement button logic (Daniele Viganò <daniele@vigano.me>)
- Add random MAC button (Daniele Viganò <daniele@vigano.me>)
- Merge pull request #467 from daniviga/storagesort (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Merge branch 'upstream' into storagesort (Daniele Viganò <daniele@vigano.me>)
- Fix points const (retspen <anatoliy.guskov@gmail.com>)
- Fix #466 (retspen <anatoliy.guskov@gmail.com>)
- Fix #429 (retspen <anatoliy.guskov@gmail.com>)
- Add timeline to graph on instance page (retspen <anatoliy.guskov@gmail.com>)
- Refactoring (retspen <anatoliy.guskov@gmail.com>)
- pep8 fixed (retspen <anatoliy.guskov@gmail.com>)
- Fix removing points (retspen <anatoliy.guskov@gmail.com>)
- Testing timeframe on performance graphs #454 (retspen <anatoliy.guskov@gmail.com>)
- Fix all regexp for input #458 (retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #463 from daniviga/upstream (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Use static bootstrap.min.css in base_auth.html too (Daniele Viganò <daniele@vigano.me>)
- Added OpenSuSe installer (retspen <anatoliy.guskov@gmail.com>)
- Fix #456 (retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #453 from Hyllegaard/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Fix strings not included for translation (Jens Hyllegaard <Jens.Hyllegaard@gmail.com>)
- Merge pull request #452 from Hyllegaard/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Fix a few mistakes (Jens Hyllegaard <Jens.Hyllegaard@gmail.com>)
- Merge pull request #450 from Hyllegaard/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Change table columns width (Daniele Viganò <daniele@vigano.me>)
- Add sorting feature to storage list table (Daniele Viganò <daniele@vigano.me>)
- Remove a space (Daniele Viganò <daniele@vigano.me>)
- Merge branch 'master' of github.com:retspen/webvirtmgr (retspen <anatoliy.guskov@gmail.com>)
- Fix iOS button position (retspen <anatoliy.guskov@gmail.com>)
- Completed Danish translation (Jens Hyllegaard <Jens.Hyllegaard@gmail.com>)
- Merge pull request #430 from Nowaker/feature/mount-iso-to-arbitrary-domains (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Return bootstap 3.0 (retspen <anatoliy.guskov@gmail.com>)
- Change menu (retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #449 from junkb/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Add Danish locale #447 (retspen <anatoliy.guskov@gmail.com>)
- Merge branch 'master' of github.com:retspen/webvirtmgr (retspen <anatoliy.guskov@gmail.com>)
- Fix #448 (retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #446 from daniviga/upstream (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Merge branch 'misc_grammar' (junkb <junkb@bitrate.net>)
- minor adjustments in some wording and grammar (junkb <junkb@bitrate.net>)
- Merge branch 'nfs_storage' more indentation fixes (junkb <junkb@bitrate.net>)
- more indentation fixes (junkb <junkb@bitrate.net>)
- Merge branch 'nfs_storage' fixes indentation for compliance with pep 8 (junkb <junkb@bitrate.net>)
- fixes indentation for compliance with pep 8 (junkb <junkb@bitrate.net>)
- Merge branch 'nfs_storage' adds support for nfs storage pools (junkb <junkb@bitrate.net>)
- adds support for netfs storage pools (junkb <junkb@bitrate.net>)
- Merge remote-tracking branch 'upstream/master' (junkb <junkb@bitrate.net>)
- Upload locale (retspen <anatoliy.guskov@gmail.com>)
- Cleanup unwanted spaces (Daniele Viganò <daniele@vigano.me>)
- Use lowercase names in template's dictSort (Daniele Viganò <daniele@vigano.me>)
- Change ts sort algorithm to sortText (Daniele Viganò <daniele@vigano.me>)
- Merge pull request #444 from daniviga/upstream (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Sort instances by status then name directly in template (Daniele Viganò <daniele@vigano.me>)
- Merge pull request #442 from daniviga/upstream (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Change tablesorter css to be compliant with new js version (Daniele Viganò <daniele@vigano.me>)
- Change sort order to be compliant with new js version (Daniele Viganò <daniele@vigano.me>)
- Remove sorting on the 4th column (Daniele Viganò <daniele@vigano.me>)
- Update jquery.tablesorter.js to 2.17.8 (Daniele Viganò <daniele@vigano.me>)
- Merge pull request #438 from tolbkni/centos (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Merge pull request #439 from daniviga/upstream (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Fix indentation (Daniele Viganò <daniele@vigano.me>)
- Make instances list sortable by coulumns (Daniele Viganò <daniele@vigano.me>)
- kvm package not available for CentOS 6, use qemu-kvm instead of. (Tolbkni Kao <tolbkni@gmail.com>)
- Fixed installing qemu-kvm for CentOS 7 (retspen <anatoliy.guskov@gmail.com>)
- Added start up script for CentOS 7 (retspen <anatoliy.guskov@gmail.com>)
- Fix #435 (retspen <anatoliy.guskov@gmail.com>)
- force delete VM with existing snapshots (Nowaker <damian.nowak@geozone.pl>)
- live mount ISO (Nowaker <damian.nowak@geozone.pl>)
- fix an infinite loop when attaching an ISO to non-WebVirtMgr domain (Nowaker <damian.nowak@geozone.pl>)
- Fix #417 (retspen <anatoliy.guskov@gmail.com>)
- Merge branch 'master' of github.com:retspen/webvirtmgr (retspen <anatoliy.guskov@gmail.com>)
- Add 768Mb (retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #421 from aprt5pr/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Merge pull request #423 from MaddinXx/custom-memory (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- use i18n trans (Michel Käser <mk@frontender.ch>)
- allow setting a custom memory limit (Michel Käser <mk@frontender.ch>)
- Merge branch 'master' of https://github.com/retspen/webvirtmgr (Michel Käser <mk@frontender.ch>)
- Added 3G of RAM to instance view (Roman Kudlay <roman@kudlay.pro>)
- Fix IPv6 gateway validation error message (aprt5pr <aprt5pr@users.noreply.github.com>)
- Fix #415 (retspen <anatoliy.guskov@gmail.com>)
- Remove exception type (retspen <anatoliy.guskov@gmail.com>)
- Update version (retspen <anatoliy.guskov@gmail.com>)
- Fix "Shutoff" label (retspen <anatoliy.guskov@gmail.com>)
- Merge branch 'redesign' of git://github.com/MaddinXx/webvirtmgr into MaddinXx-redesign (retspen <anatoliy.guskov@gmail.com>)
- Fix #406 (retspen <anatoliy.guskov@gmail.com>)
- tell charts to be responsive (Michel Käser <mk@frontender.ch>)
- use labels for colored text (Michel Käser <mk@frontender.ch>)
- Fix #385 (retspen <anatoliy.guskov@gmail.com>)
- Fix tempalate (retspen <anatoliy.guskov@gmail.com>)
- Add file for merge (retspen <anatoliy.guskov@gmail.com>)
- Merge branch 'master' of github.com:retspen/webvirtmgr (retspen <anatoliy.guskov@gmail.com>)
- Remove ipv4_range func in veiw (retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #405 from MaddinXx/vnc-pwd-500 (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Merge pull request #404 from Nowaker/patch-1 (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Add support for local socket connections (Rafi Khardalian <rafi@metacloud.com>)
- Instances table should not be cropped cause of the buttons (Michel Käser <mk@frontender.ch>)
- should fix CI (pep8)... (Michel Käser <mk@frontender.ch>)
- fixes TypeError: tostring() got an unexpected keyword argument 'method' (Michel Käser <mk@frontender.ch>)
- fix typo in instance/views.py (Damian Nowak <spam@nowaker.net>)
- check if returned value is an array (fixes NonType object is unsubscriptable) (Michel Käser <mk@frontender.ch>)
- fix table on create page (Michel Käser <mk@frontender.ch>)
- Responsive design (Michel Käser <mk@frontender.ch>)
- Fix pep8 (retspen <anatoliy.guskov@gmail.com>)
- Fix pep8 and remove default Metadata (retspen <anatoliy.guskov@gmail.com>)
- Rebuilded host_is_up method (unuseful when connection is lost) (retspen <anatoliy.guskov@gmail.com>)
- Fix #398 (retspen <anatoliy.guskov@gmail.com>)
- Merge pull request #397 from winstona/master (Anatoliy Guskov <anatoliy.guskov@gmail.com>)
- Temporary fix for libvirt > libvirt-0.10.2-41 (retspen <anatoliy.guskov@gmail.com>)
- Fix connection (retspen <anatoliy.guskov@gmail.com>)
- Fix docs (retspen <anatoliy.guskov@gmail.com>)
- Merge branch 'connection-pooling-pr' of git://github.com/myvision-de/webvirtmgr into myvision-de-connection-pooling-pr (retspen <anatoliy.guskov@gmail.com>)
- add unsafe parameter to migrate (Winston Ametsitsi <w.wonton@gmail.com>)
- Fix #392 (retspen <anatoliy.guskov@gmail.com>)
- fix pep8 (Philipp Steinhardt <steinhardt.philipp@gmail.com>)
- remove socket host active check as it leads to weird messages in auth.log (at least for ssh connections). Connection error messages should be enough to determine what went wrong. In the future it may also be possible to set "connection failed" based on the last error code returned by libvirt. (Philipp Steinhardt <steinhardt.philipp@gmail.com>)
- add new settings and explanation to settings.py and local_settings.py.example (Philipp Steinhardt <steinhardt.philipp@gmail.com>)
- Implemented connection pooling in vrtManager/connection.py:   * connections are shared among threads (not processes)   * settings LIBVIRT_KEEPALIVE_INTERVAL and LIBVIRT_KEEPALIVE_COUNT added to control the clientside keepalive protocol   * one connection per host will be created and used as long as it is alive (Philipp Steinhardt <steinhardt.philipp@gmail.com>)
